Generated by `dagster project scaffold` on 2022-12-14 using master (post 1.1.6)
Added the `flask` dependency to setup.py, since it provides the `flask` command.
Added `dagster-cloud` to setup.py to satisfy new check.